Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1746)

Unified Diff: media/base/mime_util_internal.h

Issue 1896983004: Rename misleading |is_ambiguous| parameter Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/base/mime_util_internal.cc » ('j') | media/base/mime_util_internal.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/mime_util_internal.h
diff --git a/media/base/mime_util_internal.h b/media/base/mime_util_internal.h
index 67396cf654e11271680c048d17a76daeafc1c2ec..4096a0da2d098306b5b4f3fb9769ebe5be305fa8 100644
--- a/media/base/mime_util_internal.h
+++ b/media/base/mime_util_internal.h
@@ -98,29 +98,28 @@ class MEDIA_EXPORT MimeUtil {
const CodecSet& codecs_list,
bool is_proprietary_mime_type);
- // Returns IsSupported if all codec IDs in |codecs| are unambiguous and are
- // supported in |mime_type_lower_case|. MayBeSupported is returned if at least
- // one codec ID in |codecs| is ambiguous but all the codecs are supported.
+ // Returns IsSupported if all codec IDs in |codecs| are unambiguous, known to
ddorwin 2016/04/18 23:43:37 "known to be supported" here, which is not "confid
DaleCurtis 2016/04/20 19:18:54 Yeah, this is just redundant. It doesn't make sens
ddorwin 2016/04/21 00:50:30 It turns out this was a bit of a bad example. I've
+ // be supported, and are supported in |mime_type_lower_case|. MayBeSupported
xhwang 2016/04/19 23:59:42 nit and not for this CL: Since "maybe" is one word
ddorwin 2016/04/21 00:50:30 I believe this is based on "the codec may be suppo
xhwang 2016/04/21 05:59:44 Acknowledged.
+ // is returned if all the codecs are supported but at least one codec ID in
+ // |codecs| is ambiguous or not confidently known to be supported.
DaleCurtis 2016/04/20 19:18:54 maybe something like "support can not be determine
ddorwin 2016/04/21 00:50:30 Reworded. WDYT?
// IsNotSupported is returned if |mime_type_lower_case| is not supported or at
- // least one is not supported in |mime_type_lower_case|. |is_encrypted| means
- // the codec will be used with encrypted blocks.
+ // least one of the |codecs| is not supported in |mime_type_lower_case|.
+ // |is_encrypted| means the codec will be used with encrypted blocks.
SupportsType AreSupportedCodecs(const CodecSet& supported_codecs,
xhwang 2016/04/19 23:59:42 What is this parameter for? It's not documented an
ddorwin 2016/04/21 00:50:30 Done.
const std::vector<std::string>& codecs,
const std::string& mime_type_lower_case,
bool is_encrypted) const;
// Converts a codec ID into an Codec enum value and indicates
xhwang 2016/04/19 23:59:42 nit: s/an/a also needs reflow
ddorwin 2016/04/21 00:50:30 Done.
- // whether the conversion was ambiguous.
+ // whether the specified codec, including profile, etc., is is known supported
xhwang 2016/04/19 23:59:42 s/is is/is/
ddorwin 2016/04/21 00:50:30 Done.
+ // ("probably") or not ("maybe"), such as a potentially unsupported profile.
// Returns true if this method was able to map |codec_id| to a specific
// Codec enum value. |codec| and |is_ambiguous| are only valid if true
// is returned. Otherwise their value is undefined after the call.
- // |is_ambiguous| is true if |codec_id| did not have enough information to
- // unambiguously determine the proper Codec enum value. If |is_ambiguous|
- // is true |codec| contains the best guess for the intended Codec enum value.
// |is_encrypted| means the codec will be used with encrypted blocks.
bool StringToCodec(const std::string& codec_id,
Codec* codec,
- bool* is_ambiguous,
+ bool* is_known_supported,
xhwang 2016/04/19 23:59:42 Thanks for the background context on naming. So is
ddorwin 2016/04/21 00:50:30 No, it is not strictly the opposite. Ambiguous (no
xhwang 2016/04/21 05:59:44 |is_probably_supported| is probably better, but no
@@ -98,29 +98,28 @@ class MEDIA_EXPORT MimeUtil {
// Returns true if this method was able to map |codec_id| to a specific
- // Codec enum value. |codec| and |is_ambiguous| are only valid if true
+ // Codec enum value. |codec| and |is_known_supported| are only valid if true
// is returned. Otherwise their value is undefined after the call.
ddorwin 2016/04/21 17:30:48 Done.
bool is_encrypted) const;
// Returns true if |codec| is supported when contained in
« no previous file with comments | « no previous file | media/base/mime_util_internal.cc » ('j') | media/base/mime_util_internal.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698